@@ -86,12 +86,23 @@ def process(smpp_client, queue):
                         REQUEST_ID=request_id
                         )
                     try:
-                        smpp_client.send_sms(
-                            msisdn,
-                            message,
-                            request_id=request_id,
-                            sender_id=sender_id
-                            )
+                        # international
+                        if document['json'].get("intl"):
+                            LOGS.logger.info("intl")
+                            smpp_client.send_sms(
+                                msisdn,
+                                message,
+                                intl=True,
+                                request_id=request_id,
+                                sender_id=sender_id
+                                )
+                        else:
+                            smpp_client.send_sms(
+                                msisdn,
+                                message,
+                                request_id=request_id,
+                                sender_id=sender_id
+                                )
                     except Exception as exc:
                         log_msg = (
                             "Erreur survenue lors de l'envoi: {}"
