@@ -47,10 +47,15 @@ class Client(object):
         except smpplib.exceptions.ConnectionError:
             raise SystemError("Impossible de se connecter au SMSC")
         else:
-            self.smpp_client.bind_transceiver(
-                system_id=CONFIG[smpp_config]['username'],
-                password=CONFIG[smpp_config]['password']
-                )
+            try:
+                self.smpp_client.bind_transceiver(
+                    system_id=CONFIG[smpp_config]['username'],
+                    password=CONFIG[smpp_config]['password']
+                    )
+            except Exception as e:
+                LOGS.logger.info('Error:Connect bind_transceiver{}'.format(e))
+            else:
+                LOGS.logger.info('Connect bind_transceiver')
             from threading import Thread
             t = Thread(target=self.listen)
             t.start()
@@ -196,6 +201,8 @@ class Client(object):
                 destination = '261{}'.format(msisdn[-9:])
             else:
                 destination = msisdn
+            journal.send("intl {}".format(destination))
+            journal.send("<<<<< kwargs {}".format(kwargs))
             parts, encoding_flag, msg_type_flag = smpplib.gsm.make_parts(
                 message
                 )
